Account

Struct Account 

pub struct Account {
Show 39 fields pub id: Option<String>, pub alias: Option<String>, pub currency: Option<AccountCurrency>, pub balance: Option<String>, pub created_by_user_id: Option<i32>, pub created_time: Option<String>, pub guaranteed_stop_loss_order_mode: Option<AccountGuaranteedStopLossOrderMode>, pub pl: Option<String>, pub resettable_pl: Option<String>, pub resettable_pl_time: Option<String>, pub financing: Option<String>, pub commission: Option<String>, pub guaranteed_execution_fees: Option<String>, pub margin_rate: Option<String>, pub margin_call_enter_time: Option<String>, pub margin_call_extension_count: Option<i32>, pub last_margin_call_extension_time: Option<String>, pub open_trade_count: Option<i32>, pub open_position_count: Option<i32>, pub pending_order_count: Option<i32>, pub hedging_enabled: Option<bool>, pub last_order_fill_timestamp: Option<String>, pub last_transaction_id: Option<String>, pub unrealized_pl: Option<String>, pub nav: Option<String>, pub margin_used: Option<String>, pub margin_available: Option<String>, pub position_value: Option<String>, pub margin_closeout_unrealized_pl: Option<String>, pub margin_closeout_nav: Option<String>, pub margin_closeout_margin_used: Option<String>, pub margin_closeout_percent: Option<String>, pub margin_closeout_position_value: Option<String>, pub withdrawal_limit: Option<String>, pub margin_call_margin_used: Option<String>, pub margin_call_percent: Option<String>, pub trades: Option<Vec<TradeSummary>>, pub positions: Option<Vec<Position>>, pub orders: Option<Vec<Order>>,
}
Account : The full details of a client’s Account. This includes full open Trade, open Position and pending Order representation.

Fields

id: Option<String>

The Account’s identifier

alias: Option<String>

Client-assigned alias for the Account. Only provided if the Account has an alias set

currency: Option<AccountCurrency>balance: Option<String>

The current balance of the Account.

created_by_user_id: Option<i32>

ID of the user that created the Account.

created_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

guaranteed_stop_loss_order_mode: Option<AccountGuaranteedStopLossOrderMode>pl: Option<String>

The total profit/loss realized over the lifetime of the Account.

resettable_pl: Option<String>

The total realized profit/loss for the Account since it was last reset by the client.

resettable_pl_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

financing: Option<String>

The total amount of financing paid/collected over the lifetime of the Account.

commission: Option<String>

The total amount of commission paid over the lifetime of the Account.

guaranteed_execution_fees: Option<String>

The total amount of fees charged over the lifetime of the Account for the execution of guaranteed Stop Loss Orders.

margin_rate: Option<String>

Client-provided margin rate override for the Account. The effective margin rate of the Account is the lesser of this value and the OANDA margin rate for the Account’s division. This value is only provided if a margin rate override exists for the Account.

margin_call_enter_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

margin_call_extension_count: Option<i32>

The number of times that the Account’s current margin call was extended.

last_margin_call_extension_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

open_trade_count: Option<i32>

The number of Trades currently open in the Account.

open_position_count: Option<i32>

The number of Positions currently open in the Account.

pending_order_count: Option<i32>

The number of Orders currently pending in the Account.

hedging_enabled: Option<bool>

Flag indicating that the Account has hedging enabled.

last_order_fill_timestamp: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

last_transaction_id: Option<String>

The ID of the last Transaction created for the Account.

unrealized_pl: Option<String>

The total unrealized profit/loss for all Trades currently open in the Account.

nav: Option<String>

The net asset value of the Account. Equal to Account balance unrealizedPL.

margin_used: Option<String>

Margin currently used for the Account.

margin_available: Option<String>

Margin available for Account currency.

position_value: Option<String>

The value of the Account’s open positions represented in the Account’s home currency.

margin_closeout_unrealized_pl: Option<String>

The Account’s margin closeout unrealized PL.

margin_closeout_nav: Option<String>

The Account’s margin closeout NAV.

margin_closeout_margin_used: Option<String>

The Account’s margin closeout margin used.

margin_closeout_percent: Option<String>

The Account’s margin closeout percentage. When this value is 1.0 or above the Account is in a margin closeout situation.

margin_closeout_position_value: Option<String>

The value of the Account’s open positions as used for margin closeout calculations represented in the Account’s home currency.

withdrawal_limit: Option<String>

The current WithdrawalLimit for the account which will be zero or a positive value indicating how much can be withdrawn from the account.

margin_call_margin_used: Option<String>

The Account’s margin call margin used.

margin_call_percent: Option<String>

The Account’s margin call percentage. When this value is 1.0 or above the Account is in a margin call situation.

trades: Option<Vec<TradeSummary>>

The details of the Trades currently open in the Account.

positions: Option<Vec<Position>>

The details all Account Positions.

orders: Option<Vec<Order>>

The details of the Orders currently pending in the Account.

Implementations

Source

impl Account

pub fn new() -> Account

The full details of a client’s Account. This includes full open Trade, open Position and pending Order representation.