pub struct AccountChangesState {Show 16 fields
pub unrealized_pl: Option<String>,
pub nav: Option<String>,
pub margin_used: Option<String>,
pub margin_available: Option<String>,
pub position_value: Option<String>,
pub margin_closeout_unrealized_pl: Option<String>,
pub margin_closeout_nav: Option<String>,
pub margin_closeout_margin_used: Option<String>,
pub margin_closeout_percent: Option<String>,
pub margin_closeout_position_value: Option<String>,
pub withdrawal_limit: Option<String>,
pub margin_call_margin_used: Option<String>,
pub margin_call_percent: Option<String>,
pub orders: Option<Vec<DynamicOrderState>>,
pub trades: Option<Vec<CalculatedTradeState>>,
pub positions: Option<Vec<CalculatedPositionState>>,
}Expand description
AccountChangesState : An AccountChangesState Object is used to represent an Account’s current price-dependent state. Price-dependent Account state is dependent on OANDA’s current Prices, and includes things like unrealized PL, NAV and Trailing Stop Loss Order state.
Fields
unrealized_pl: Option<String>The total unrealized profit/loss for all Trades currently open in the Account.
The net asset value of the Account. Equal to Account balance unrealizedPL.
margin_used: Option<String>Margin currently used for the Account.
margin_available: Option<String>Margin available for Account currency.
position_value: Option<String>The value of the Account’s open positions represented in the Account’s home currency.
margin_closeout_unrealized_pl: Option<String>The Account’s margin closeout unrealized PL.
The Account’s margin closeout NAV.
margin_closeout_margin_used: Option<String>The Account’s margin closeout margin used.
margin_closeout_percent: Option<String>The Account’s margin closeout percentage. When this value is 1.0 or above the Account is in a margin closeout situation.
margin_closeout_position_value: Option<String>The value of the Account’s open positions as used for margin closeout calculations represented in the Account’s home currency.
withdrawal_limit: Option<String>The current WithdrawalLimit for the account which will be zero or a positive value indicating how much can be withdrawn from the account.
margin_call_margin_used: Option<String>The Account’s margin call margin used.
margin_call_percent: Option<String>The Account’s margin call percentage. When this value is 1.0 or above the Account is in a margin call situation.
orders: Option<Vec<DynamicOrderState>>The price-dependent state of each pending Order in the Account.
trades: Option<Vec<CalculatedTradeState>>The price-dependent state for each open Trade in the Account.
positions: Option<Vec<CalculatedPositionState>>The price-dependent state for each open Position in the Account.
Implementations
Sourceimpl AccountChangesState
impl AccountChangesState
Sourcepub fn new() -> AccountChangesState
pub fn new() -> AccountChangesState
An AccountChangesState Object is used to represent an Account’s current price-dependent state. Price-dependent Account state is dependent on OANDA’s current Prices, and includes things like unrealized PL, NAV and Trailing Stop Loss Order state.