pub struct Candlestick {
pub time: Option<String>,
pub bid: Option<Box<CandlestickData>>,
pub ask: Option<Box<CandlestickData>>,
pub mid: Option<Box<CandlestickData>>,
pub volume: Option<i32>,
pub complete: Option<bool>,
}Expand description
Candlestick : The Candlestick representation
Fields
time: Option<String>A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).
bid: Option<Box<CandlestickData>>ask: Option<Box<CandlestickData>>mid: Option<Box<CandlestickData>>volume: Option<i32>The number of prices created during the time-range represented by the candlestick.
complete: Option<bool>A flag indicating if the candlestick is complete. A complete candlestick is one whose ending time is not in the future.
Implementations
Sourceimpl Candlestick
impl Candlestick
Sourcepub fn new() -> Candlestick
pub fn new() -> Candlestick
The Candlestick representation