ClientExtensions

Struct ClientExtensions 

pub struct ClientExtensions {
    pub id: Option<String>,
    pub tag: Option<String>,
    pub comment: Option<String>,
}
ClientExtensions : A ClientExtensions object allows a client to attach a clientID, tag and comment to Orders and Trades in their Account. Do not set, modify, or delete this field if your account is associated with MT4.

Fields

id: Option<String>

The Client ID of the Order/Trade

tag: Option<String>

A tag associated with the Order/Trade

comment: Option<String>

A comment associated with the Order/Trade

Implementations

Source

impl ClientExtensions

pub fn new() -> ClientExtensions

A ClientExtensions object allows a client to attach a clientID, tag and comment to Orders and Trades in their Account. Do not set, modify, or delete this field if your account is associated with MT4.