ClientPrice

Struct ClientPrice 

pub struct ClientPrice {
    pub type: Option<String>,
    pub instrument: Option<InstrumentName>,
    pub time: Option<String>,
    pub status: Option<PriceStatus>,
    pub tradeable: Option<bool>,
    pub bids: Option<Vec<PriceBucket>>,
    pub asks: Option<Vec<PriceBucket>>,
    pub closeout_bid: Option<f64>,
    pub closeout_ask: Option<f64>,
    pub quote_home_conversion_factors: Option<Box<QuoteHomeConversionFactors>>,
    pub units_available: Option<Box<UnitsAvailable>>,
}
ClientPrice : The specification of an Account-specific Price.

Fields

type: Option<String>

The string "PRICE". Used to identify the a Price object when found in a stream.

instrument: Option<InstrumentName>time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

status: Option<PriceStatus>tradeable: Option<bool>

Flag indicating if the Price is tradeable or not

bids: Option<Vec<PriceBucket>>

The list of prices and liquidity available on the Instrument’s bid side. It is possible for this list to be empty if there is no bid liquidity currently available for the Instrument in the Account.

asks: Option<Vec<PriceBucket>>

The list of prices and liquidity available on the Instrument’s ask side. It is possible for this list to be empty if there is no ask liquidity currently available for the Instrument in the Account.

closeout_bid: Option<f64>

The closeout bid Price. This Price is used when a bid is required to closeout a Position (margin closeout or manual) yet there is no bid liquidity. The closeout bid is never used to open a new position.

closeout_ask: Option<f64>

The closeout ask Price. This Price is used when a ask is required to closeout a Position (margin closeout or manual) yet there is no ask liquidity. The closeout ask is never used to open a new position.

quote_home_conversion_factors: Option<Box<QuoteHomeConversionFactors>>units_available: Option<Box<UnitsAvailable>>

Implementations

Source

impl ClientPrice

pub fn new() -> ClientPrice

The specification of an Account-specific Price.