pub struct CreateOrderBadRequestResponse {
pub error_code: Option<String>,
pub error_message: Option<String>,
pub last_transaction_id: Option<String>,
pub related_transaction_ids: Option<Vec<i32>>,
pub order_reject_transaction: Option<Box<Transaction>>,
}Fields
error_code: Option<String>The code of the error that has occurred. This field may not be returned for some errors.
error_message: Option<String>The human-readable description of the error that has occurred.
last_transaction_id: Option<String>The ID of the most recent Transaction created for the Account
The IDs of all Transactions that were created while satisfying the request.
order_reject_transaction: Option<Box<Transaction>>Implementations