Instrument

Struct Instrument 

pub struct Instrument {
Show 13 fields pub name: Option<InstrumentName>, pub type: Option<InstrumentType>, pub display_name: Option<String>, pub pip_location: Option<i32>, pub display_precision: Option<i32>, pub trade_units_precision: Option<i32>, pub minimum_trade_size: Option<String>, pub maximum_trailing_stop_distance: Option<String>, pub minimum_trailing_stop_distance: Option<String>, pub maximum_position_size: Option<String>, pub maximum_order_units: Option<String>, pub margin_rate: Option<String>, pub commission: Option<Box<InstrumentComission>>,
}
Instrument : Full specification of an Instrument.

Fields

name: Option<InstrumentName>type: Option<InstrumentType>display_name: Option<String>

The display name of the Instrument

pip_location: Option<i32>

The location of the "pip" for this instrument. The decimal position of the pip in this Instrument’s price can be found at 10 ^ pipLocation (e.g. -4 pipLocation results in a decimal pip position of 10 ^ -4 = 0.0001).

display_precision: Option<i32>

The number of decimal places that should be used to display prices for this instrument. (e.g. a displayPrecision of 5 would result in a price of "1" being displayed as "1.00000")

trade_units_precision: Option<i32>

The amount of decimal places that may be provided when specifying the number of units traded for this instrument.

minimum_trade_size: Option<String>

The smallest number of units allowed to be traded for this instrument.

maximum_trailing_stop_distance: Option<String>

The maximum trailing stop distance allowed for a trailing stop loss created for this instrument. Specified in price units.

minimum_trailing_stop_distance: Option<String>

The minimum trailing stop distance allowed for a trailing stop loss created for this instrument. Specified in price units.

maximum_position_size: Option<String>

The maximum position size allowed for this instrument. Specified in units.

maximum_order_units: Option<String>

The maximum units allowed for an Order placed for this instrument. Specified in units.

margin_rate: Option<String>

The margin rate for this instrument.

commission: Option<Box<InstrumentComission>>

Implementations

Source

impl Instrument

pub fn new() -> Instrument

Full specification of an Instrument.