pub struct Order {
pub id: Option<i32>,
pub create_time: Option<String>,
pub state: Option<OrderState>,
pub client_extensions: Option<Box<ClientExtensions>>,
}Expand description
Order : The base Order definition specifies the properties that are common to all Orders.
Fields
id: Option<i32>The Order’s identifier, unique within the Order’s Account.
create_time: Option<String>A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).
state: Option<OrderState>client_extensions: Option<Box<ClientExtensions>>Implementations