pub struct PositionBook {
pub instrument: Option<InstrumentName>,
pub time: Option<String>,
pub price: Option<f64>,
pub bucket_width: Option<f64>,
pub buckets: Option<Vec<PositionBookBucket>>,
}Expand description
PositionBook : The representation of an instrument’s position book at a point in time
Fields
instrument: Option<InstrumentName>time: Option<String>A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).
price: Option<f64>The price (midpoint) for the position book’s instrument at the time of the position book snapshot
bucket_width: Option<f64>The price width for each bucket. Each bucket covers the price range from the bucket’s price to the bucket’s price + bucketWidth.
buckets: Option<Vec<PositionBookBucket>>The partitioned position book, divided into buckets using a default bucket width. These buckets are only provided for price ranges which actually contain order or position data.
Implementations
Sourceimpl PositionBook
impl PositionBook
Sourcepub fn new() -> PositionBook
pub fn new() -> PositionBook
The representation of an instrument’s position book at a point in time