pub struct PositionSide {
pub units: Option<f64>,
pub average_price: Option<f64>,
pub trade_ids: Option<Vec<i32>>,
pub pl: Option<f64>,
pub unrealized_pl: Option<f64>,
pub resettable_pl: Option<f64>,
pub financing: Option<f64>,
pub guaranteed_execution_fees: Option<f64>,
}Expand description
PositionSide : The representation of a Position for a single direction (long or short).
Fields
units: Option<f64>Number of units in the position (negative value indicates short position, positive indicates long position).
average_price: Option<f64>Volume-weighted average of the underlying Trade open prices for the Position.
trade_ids: Option<Vec<i32>>List of the open Trade IDs which contribute to the open Position.
pl: Option<f64>Profit/loss realized by the PositionSide over the lifetime of the Account.
unrealized_pl: Option<f64>The unrealized profit/loss of all open Trades that contribute to this PositionSide.
resettable_pl: Option<f64>Profit/loss realized by the PositionSide since the Account’s resettablePL was last reset by the client.
financing: Option<f64>The total amount of financing paid/collected for this PositionSide over the lifetime of the Account.
guaranteed_execution_fees: Option<f64>The total amount of fees charged over the lifetime of the Account for the execution of guaranteed Stop Loss Orders attached to Trades for this PositionSide.
Implementations
Sourceimpl PositionSide
impl PositionSide
Sourcepub fn new() -> PositionSide
pub fn new() -> PositionSide
The representation of a Position for a single direction (long or short).