pub struct ReplaceOrderResponse {
pub error_code: Option<String>,
pub error_message: Option<String>,
pub last_transaction_id: Option<String>,
pub related_transaction_ids: Option<Vec<i32>>,
pub order_cancel_transaction: Option<Box<OrderCancelTransaction>>,
pub order_create_transaction: Option<Box<Transaction>>,
pub order_fill_transaction: Option<Box<OrderFillTransaction>>,
pub order_reissue_transaction: Option<Box<Transaction>>,
pub order_reissue_reject_transaction: Option<Box<Transaction>>,
pub replacing_order_cancel_transaction: Option<Box<OrderCancelTransaction>>,
}Fields
error_code: Option<String>The code of the error that has occurred. This field may not be returned for some errors.
error_message: Option<String>The human-readable description of the error that has occurred.
last_transaction_id: Option<String>The ID of the most recent Transaction created for the Account
The IDs of all Transactions that were created while satisfying the request.
order_cancel_transaction: Option<Box<OrderCancelTransaction>>order_create_transaction: Option<Box<Transaction>>order_fill_transaction: Option<Box<OrderFillTransaction>>order_reissue_transaction: Option<Box<Transaction>>order_reissue_reject_transaction: Option<Box<Transaction>>replacing_order_cancel_transaction: Option<Box<OrderCancelTransaction>>Implementations
Sourceimpl ReplaceOrderResponse
impl ReplaceOrderResponse
pub fn new() -> ReplaceOrderResponse