pub struct TradeExtensionsResponse {
pub last_transaction_id: Option<String>,
pub related_transaction_ids: Option<Vec<i32>>,
pub trade_client_extensions_modify_transaction: Option<Box<TradeClientExtensionsModifyTransaction>>,
}Fields
last_transaction_id: Option<String>The ID of the most recent Transaction created for the Account
The IDs of all Transactions that were created while satisfying the request.
trade_client_extensions_modify_transaction: Option<Box<TradeClientExtensionsModifyTransaction>>Implementations
Sourceimpl TradeExtensionsResponse
impl TradeExtensionsResponse
pub fn new() -> TradeExtensionsResponse