TradeOrderBase

Struct TradeOrderBase 

pub struct TradeOrderBase {
Show 19 fields pub id: Option<i32>, pub create_time: Option<String>, pub state: Option<OrderState>, pub client_extensions: Option<Box<ClientExtensions>>, pub type: Option<Type>, pub trade_id: Option<i32>, pub client_trade_id: Option<String>, pub time_in_force: Option<TradeOrderTimeInForce>, pub gtd_time: Option<String>, pub trigger_condition: Option<TradeOrderTriggerCondition>, pub filling_transaction_id: Option<i32>, pub filled_time: Option<String>, pub trade_opened_id: Option<i32>, pub trade_reduced_id: Option<i32>, pub trade_closed_ids: Option<Vec<i32>>, pub cancelling_transaction_id: Option<i32>, pub cancelled_time: Option<String>, pub replaces_order_id: Option<i32>, pub replaced_by_order_id: Option<i32>,
}
TradeOrderBase : The base Order object for TakeProfit, StopLoss and TrailingStopLoss type of orders which are connected to a trade.

Fields

id: Option<i32>

The Order’s identifier, unique within the Order’s Account.

create_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

state: Option<OrderState>client_extensions: Option<Box<ClientExtensions>>type: Option<Type>

The type of the Order.

trade_id: Option<i32>

The ID of the Trade to close when the price threshold is breached.

client_trade_id: Option<String>

The client ID of the Trade to be closed when the price threshold is breached.

time_in_force: Option<TradeOrderTimeInForce>gtd_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

trigger_condition: Option<TradeOrderTriggerCondition>filling_transaction_id: Option<i32>

ID of the Transaction that filled this Order (only provided when the Order’s state is FILLED)

filled_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

trade_opened_id: Option<i32>

Trade ID of Trade opened when the Order was filled (only provided when the Order’s state is FILLED and a Trade was opened as a result of the fill)

trade_reduced_id: Option<i32>

Trade ID of Trade reduced when the Order was filled (only provided when the Order’s state is FILLED and a Trade was reduced as a result of the fill)

trade_closed_ids: Option<Vec<i32>>

Trade IDs of Trades closed when the Order was filled (only provided when the Order’s state is FILLED and one or more Trades were closed as a result of the fill)

cancelling_transaction_id: Option<i32>

ID of the Transaction that cancelled the Order (only provided when the Order’s state is CANCELLED)

cancelled_time: Option<String>

A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).

replaces_order_id: Option<i32>

The ID of the Order that was replaced by this Order (only provided if this Order was created as part of a cancel/replace).

replaced_by_order_id: Option<i32>

The ID of the Order that replaced this Order (only provided if this Order was cancelled as part of a cancel/replace).

Implementations

Source

impl TradeOrderBase

pub fn new() -> TradeOrderBase

The base Order object for TakeProfit, StopLoss and TrailingStopLoss type of orders which are connected to a trade.