pub struct OrderFillTransaction {Show 19 fields
pub order_id: Option<i32>,
pub client_order_id: Option<String>,
pub instrument: Option<InstrumentName>,
pub units: Option<f64>,
pub gain_quote_home_conversion_factor: Option<f64>,
pub loss_quote_home_conversion_factor: Option<f64>,
pub price: Option<f64>,
pub full_vwap: Option<f64>,
pub full_price: Option<Box<ClientPrice>>,
pub reason: Option<OrderFillReason>,
pub pl: Option<f64>,
pub financing: Option<f64>,
pub commission: Option<f64>,
pub guaranteed_execution_fee: Option<f64>,
pub account_balance: Option<f64>,
pub trade_opened: Option<Box<TradeOpen>>,
pub trades_closed: Option<Vec<TradeReduce>>,
pub trade_reduced: Option<Box<TradeReduce>>,
pub half_spread_cost: Option<f64>,
}Expand description
OrderFillTransaction : An OrderFillTransaction represents the filling of an Order in the client’s Account.
Fields
order_id: Option<i32>The ID of the Order filled.
client_order_id: Option<String>The client Order ID of the Order filled (only provided if the client has assigned one).
instrument: Option<InstrumentName>units: Option<f64>The number of units filled by the OrderFill.
gain_quote_home_conversion_factor: Option<f64>This is the conversion factor in effect for the Account at the time of the OrderFill for converting any gains realized in Instrument quote units into units of the Account’s home currency.
loss_quote_home_conversion_factor: Option<f64>This is the conversion factor in effect for the Account at the time of the OrderFill for converting any losses realized in Instrument quote units into units of the Account’s home currency.
price: Option<f64>This field is now deprecated and should no longer be used. The individual tradesClosed, tradeReduced and tradeOpened fields contain the exact/official price each unit was filled at.
full_vwap: Option<f64>The price that all of the units of the OrderFill should have been filled at, in the absence of guaranteed price execution. This factors in the Account’s current ClientPrice, used liquidity and the units of the OrderFill only. If no Trades were closed with their price clamped for guaranteed stop loss enforcement, then this value will match the price fields of each Trade opened, closed, and reduced, and they will all be the exact same.
full_price: Option<Box<ClientPrice>>reason: Option<OrderFillReason>pl: Option<f64>The profit or loss incurred when the Order was filled.
financing: Option<f64>The financing paid or collected when the Order was filled
commission: Option<f64>The commission charged in the Account’s home currency as a result of filling the Order. The commission is always represented as a positive quantity of the Account’s home currency, however it reduces the balance in the Account.
guaranteed_execution_fee: Option<f64>The total guaranteed execution fees charged for all Trades opened, closed or reduced with guaranteed Stop Loss Orders.
account_balance: Option<f64>The Account’s balance after the Order was filled.
trade_opened: Option<Box<TradeOpen>>trades_closed: Option<Vec<TradeReduce>>The Trades that were closed when the Order was filled (only provided if filling the Order resulted in a closing open Trades).
trade_reduced: Option<Box<TradeReduce>>half_spread_cost: Option<f64>The half spread cost for the OrderFill, which is the sum of the halfSpreadCost values in the tradeOpened, tradesClosed and tradeReduced fields. This can be a positive or negative value and is represented in the home currency of the Account.
Implementations
Sourceimpl OrderFillTransaction
impl OrderFillTransaction
Sourcepub fn new() -> OrderFillTransaction
pub fn new() -> OrderFillTransaction
An OrderFillTransaction represents the filling of an Order in the client’s Account.